#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   prob_trans.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 13:58:25
# @Modified By: thepoy

from . import TransType

P: TransType
